@@ -7,7 +7,9 @@ from .constants import (
     Avogadro,
     c_light,
     c_light_sq,
+    e_SI,
     e_sq,
+    electronvolt,
     eminus,
     eplus,
     h_Planck,
@@ -32,7 +34,9 @@ __all__ = (
     "c_light",
     "c_light_sq",
     "constants",
+    "e_SI",
     "e_sq",
+    "electronvolt",
     "eminus",
     "eplus",
     "h_Planck",
